@@ -168,6 +168,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "io_cancel", 3 },
 	{ "io_destroy", 1 },
 	{ "io_getevents", 4 },
+	{ "io_pgetevents", 292 },
 	{ "io_setup", 0 },
 	{ "io_submit", 2 },
 	{ "ioctl", 29 },
@@ -177,7 +178,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "ioprio_set", 30 },
 	{ "ipc", __PNR_ipc },
 	{ "kcmp", 272 },
-	{ "kexec_file_load", __PNR_kexec_file_load },
+	{ "kexec_file_load", 294 },
 	{ "kexec_load", 104 },
 	{ "keyctl", 219 },
 	{ "kill", 129 },
@@ -296,6 +297,7 @@ const struct arch_syscall_def aarch64_syscall_table[] = { \
 	{ "request_key", 218 },
 	{ "restart_syscall", 128 },
 	{ "rmdir", __PNR_rmdir },
+	{ "rseq", 293 },
 	{ "rt_sigaction", 134 },
 	{ "rt_sigpending", 136 },
 	{ "rt_sigprocmask", 135 },
