@@ -37,7 +37,7 @@
 #define __SCMP_NR_BASE			__SCMP_NR_OABI_SYSCALL_BASE
 #endif
 
-/* NOTE: based on Linux 4.9 */
+/* NOTE: based on Linux 4.15-rc7 */
 const struct arch_syscall_def arm_syscall_table[] = { \
 	/* NOTE: arm_sync_file_range() and sync_file_range2() share values */
 	{ "_llseek", (__SCMP_NR_BASE + 140) },
@@ -134,6 +134,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "get_mempolicy", (__SCMP_NR_BASE + 320) },
 	{ "get_robust_list", (__SCMP_NR_BASE + 339) },
 	{ "get_thread_area", __PNR_get_thread_area },
+	{ "get_tls", (__SCMP_NR_BASE + (__SCMP_ARM_NR_BASE + 6)) },
 	{ "getcpu", (__SCMP_NR_BASE + 345) },
 	{ "getcwd", (__SCMP_NR_BASE + 183) },
 	{ "getdents", (__SCMP_NR_BASE + 141) },
@@ -179,6 +180,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "io_cancel", (__SCMP_NR_BASE + 247) },
 	{ "io_destroy", (__SCMP_NR_BASE + 244) },
 	{ "io_getevents", (__SCMP_NR_BASE + 245) },
+	{ "io_pgetevents", (__SCMP_NR_BASE + 399) },
 	{ "io_setup", (__SCMP_NR_BASE + 243) },
 	{ "io_submit", (__SCMP_NR_BASE + 246) },
 	{ "ioctl", (__SCMP_NR_BASE + 54) },
@@ -307,6 +309,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "request_key", (__SCMP_NR_BASE + 310) },
 	{ "restart_syscall", (__SCMP_NR_BASE +  0) },
 	{ "rmdir", (__SCMP_NR_BASE + 40) },
+	{ "rseq", (__SCMP_NR_BASE + 398) },
 	{ "rt_sigaction", (__SCMP_NR_BASE + 174) },
 	{ "rt_sigpending", (__SCMP_NR_BASE + 176) },
 	{ "rt_sigprocmask", (__SCMP_NR_BASE + 175) },
@@ -316,9 +319,11 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "rt_sigtimedwait", (__SCMP_NR_BASE + 177) },
 	{ "rt_tgsigqueueinfo", (__SCMP_NR_BASE + 363) },
 	{ "rtas", __PNR_rtas },
+	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
 	{ "s390_pci_mmio_read", __PNR_s390_pci_mmio_read },
 	{ "s390_pci_mmio_write", __PNR_s390_pci_mmio_write },
 	{ "s390_runtime_instr", __PNR_s390_runtime_instr },
+	{ "s390_sthyi", __PNR_s390_sthyi },
 	{ "sched_get_priority_max", (__SCMP_NR_BASE + 159) },
 	{ "sched_get_priority_min", (__SCMP_NR_BASE + 160) },
 	{ "sched_getaffinity", (__SCMP_NR_BASE + 242) },
@@ -404,6 +409,7 @@ const struct arch_syscall_def arm_syscall_table[] = { \
 	{ "stat64", (__SCMP_NR_BASE + 195) },
 	{ "statfs", (__SCMP_NR_BASE + 99) },
 	{ "statfs64", (__SCMP_NR_BASE + 266) },
+	{ "statx", (__SCMP_NR_BASE + 397) },
 	{ "stime", __PNR_stime },
 	{ "stty", __PNR_stty },
 	{ "subpage_prot", __PNR_subpage_prot },
