@@ -3,12 +3,13 @@
  * Author: Jan Willeke <willeke@linux.vnet.com.com>
  */
 
-#ifndef _ARCH_s390_H
-#define _ARCH_s390_H
+#ifndef _ARCH_S390_H
+#define _ARCH_S390_H
 
 #include <inttypes.h>
 
 #include "arch.h"
+#include "db.h"
 #include "system.h"
 
 #define s390_arg_count_max		6
@@ -18,6 +19,11 @@ extern const struct arch_def arch_def_s390;
 
 int s390_syscall_resolve_name(const char *name);
 const char *s390_syscall_resolve_num(int num);
-const char *s390_syscall_iterate_name(unsigned int spot);
+
+const struct arch_syscall_def *s390_syscall_iterate(unsigned int spot);
+
+int s390_syscall_rewrite(int *syscall);
+
+int s390_rule_add(struct db_filter *db, struct db_api_rule_list *rule);
 
 #endif
