@@ -10,7 +10,7 @@
 #include "arch.h"
 #include "arch-s390x.h"
 
-/* NOTE: based on Linux 4.9 */
+/* NOTE: based on Linux 4.15-rc7 */
 const struct arch_syscall_def s390x_syscall_table[] = { \
 	{ "_llseek", __PNR__llseek },
 	{ "_newselect", __PNR__newselect },
@@ -106,6 +106,7 @@ const struct arch_syscall_def s390x_syscall_table[] = { \
 	{ "get_mempolicy", 269 },
 	{ "get_robust_list", 305 },
 	{ "get_thread_area", __PNR_get_thread_area },
+	{ "get_tls", __PNR_get_tls },
 	{ "getcpu", 311 },
 	{ "getcwd", 183 },
 	{ "getdents", 141 },
@@ -151,6 +152,7 @@ const struct arch_syscall_def s390x_syscall_table[] = { \
 	{ "io_cancel", 247 },
 	{ "io_destroy", 244 },
 	{ "io_getevents", 245 },
+	{ "io_pgetevents", 382 },
 	{ "io_setup", 243 },
 	{ "io_submit", 246 },
 	{ "ioctl", 54 },
@@ -160,7 +162,7 @@ const struct arch_syscall_def s390x_syscall_table[] = { \
 	{ "ioprio_set", 282 },
 	{ "ipc", 117 },
 	{ "kcmp", 343 },
-	{ "kexec_file_load", __PNR_kexec_file_load },
+	{ "kexec_file_load", 381 },
 	{ "kexec_load", 277 },
 	{ "keyctl", 280 },
 	{ "kill", 37 },
@@ -279,6 +281,7 @@ const struct arch_syscall_def s390x_syscall_table[] = { \
 	{ "request_key", 279 },
 	{ "restart_syscall", 7 },
 	{ "rmdir", 40 },
+	{ "rseq", 383 },
 	{ "rt_sigaction", 174 },
 	{ "rt_sigpending", 176 },
 	{ "rt_sigprocmask", 175 },
@@ -288,9 +291,11 @@ const struct arch_syscall_def s390x_syscall_table[] = { \
 	{ "rt_sigtimedwait", 177 },
 	{ "rt_tgsigqueueinfo", 330 },
 	{ "rtas", __PNR_rtas },
+	{ "s390_guarded_storage", 378 },
 	{ "s390_pci_mmio_read", 353 },
 	{ "s390_pci_mmio_write", 352 },
 	{ "s390_runtime_instr", 342 },
+	{ "s390_sthyi", 380 },
 	{ "sched_get_priority_max", 159 },
 	{ "sched_get_priority_min", 160 },
 	{ "sched_getaffinity", 240 },
@@ -376,6 +381,7 @@ const struct arch_syscall_def s390x_syscall_table[] = { \
 	{ "stat64", __PNR_stat64 },
 	{ "statfs", 99 },
 	{ "statfs64", 265 },
+	{ "statx", 379 },
 	{ "stime", __PNR_stime },
 	{ "stty", __PNR_stty },
 	{ "subpage_prot", __PNR_subpage_prot },
