@@ -168,6 +168,7 @@ const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "io_cancel", 249 },
 	{ "io_destroy", 246 },
 	{ "io_getevents", 247 },
+	{ "io_pgetevents", 385 },
 	{ "io_setup", 245 },
 	{ "io_submit", 248 },
 	{ "ioctl", 54 },
@@ -296,6 +297,7 @@ const struct arch_syscall_def x86_syscall_table[] = { \
 	{ "request_key", 287 },
 	{ "restart_syscall", 0 },
 	{ "rmdir", 40 },
+	{ "rseq", 386 },
 	{ "rt_sigaction", 174 },
 	{ "rt_sigpending", 176 },
 	{ "rt_sigprocmask", 175 },
