@@ -26,7 +26,7 @@
 #include "arch.h"
 #include "arch-x86_64.h"
 
-/* NOTE: based on Linux 4.9 */
+/* NOTE: based on Linux 4.15-rc7 */
 const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "_llseek", __PNR__llseek },
 	{ "_newselect", __PNR__newselect },
@@ -122,6 +122,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "get_mempolicy", 239 },
 	{ "get_robust_list", 274 },
 	{ "get_thread_area", 211 },
+	{ "get_tls", __PNR_get_tls },
 	{ "getcpu", 309 },
 	{ "getcwd", 79 },
 	{ "getdents", 78 },
@@ -167,6 +168,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "io_cancel", 210 },
 	{ "io_destroy", 207 },
 	{ "io_getevents", 208 },
+	{ "io_pgetevents", 333 },
 	{ "io_setup", 206 },
 	{ "io_submit", 209 },
 	{ "ioctl", 16 },
@@ -295,6 +297,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "request_key", 249 },
 	{ "restart_syscall", 219 },
 	{ "rmdir", 84 },
+	{ "rseq", 334 },
 	{ "rt_sigaction", 13 },
 	{ "rt_sigpending", 127 },
 	{ "rt_sigprocmask", 14 },
@@ -304,9 +307,11 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "rt_sigtimedwait", 128 },
 	{ "rt_tgsigqueueinfo", 297 },
 	{ "rtas", __PNR_rtas },
+	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
 	{ "s390_pci_mmio_read", __PNR_s390_pci_mmio_read },
 	{ "s390_pci_mmio_write", __PNR_s390_pci_mmio_write },
 	{ "s390_runtime_instr", __PNR_s390_runtime_instr },
+	{ "s390_sthyi", __PNR_s390_sthyi },
 	{ "sched_get_priority_max", 146 },
 	{ "sched_get_priority_min", 147 },
 	{ "sched_getaffinity", 204 },
@@ -392,6 +397,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "stat64", __PNR_stat64 },
 	{ "statfs", 137 },
 	{ "statfs64", __PNR_statfs64 },
+	{ "statx", 332 },
 	{ "stime", __PNR_stime },
 	{ "stty", __PNR_stty },
 	{ "subpage_prot", __PNR_subpage_prot },
